@@ -43,13 +43,16 @@ const std::string kIso = "urn:iso:std:iso:ts:21496:-1";
 
 TEST_F(GainMapMetadataTest, encodeMetadataThenDecode) {
   uhdr_gainmap_metadata_ext_t expected("1.0");
-  expected.max_content_boost = 100.5f;
-  expected.min_content_boost = 1.5f;
-  expected.gamma = 1.0f;
-  expected.offset_sdr = 0.0625f;
-  expected.offset_hdr = 0.0625f;
+  for (int i = 0; i < 3; i++) {
+    expected.max_content_boost[i] = 100.5f + i;
+    expected.min_content_boost[i] = 1.5f + i * 0.1f;
+    expected.gamma[i] = 1.0f + i * 0.01f;
+    expected.offset_sdr[i] = 0.0625f + i * 0.025f;
+    expected.offset_hdr[i] = 0.0625f + i * 0.025f;
+  }
   expected.hdr_capacity_min = 1.0f;
   expected.hdr_capacity_max = 10000.0f / 203.0f;
+  expected.use_base_cg = false;
 
   uhdr_gainmap_metadata_frac metadata;
   EXPECT_EQ(
@@ -71,19 +74,25 @@ TEST_F(GainMapMetadataTest, encodeMetadataThenDecode) {
                 .error_code,
             UHDR_CODEC_OK);
 
-  EXPECT_FLOAT_EQ(expected.max_content_boost, decodedUHdrMetadata.max_content_boost);
-  EXPECT_FLOAT_EQ(expected.min_content_boost, decodedUHdrMetadata.min_content_boost);
-  EXPECT_FLOAT_EQ(expected.gamma, decodedUHdrMetadata.gamma);
-  EXPECT_FLOAT_EQ(expected.offset_sdr, decodedUHdrMetadata.offset_sdr);
-  EXPECT_FLOAT_EQ(expected.offset_hdr, decodedUHdrMetadata.offset_hdr);
+  for (int i = 0; i < 3; i++) {
+    EXPECT_FLOAT_EQ(expected.max_content_boost[i], decodedUHdrMetadata.max_content_boost[i]);
+    EXPECT_FLOAT_EQ(expected.min_content_boost[i], decodedUHdrMetadata.min_content_boost[i]);
+    EXPECT_FLOAT_EQ(expected.gamma[i], decodedUHdrMetadata.gamma[i]);
+    EXPECT_FLOAT_EQ(expected.offset_sdr[i], decodedUHdrMetadata.offset_sdr[i]);
+    EXPECT_FLOAT_EQ(expected.offset_hdr[i], decodedUHdrMetadata.offset_hdr[i]);
+  }
   EXPECT_FLOAT_EQ(expected.hdr_capacity_min, decodedUHdrMetadata.hdr_capacity_min);
   EXPECT_FLOAT_EQ(expected.hdr_capacity_max, decodedUHdrMetadata.hdr_capacity_max);
+  EXPECT_EQ(expected.use_base_cg, decodedUHdrMetadata.use_base_cg);
 
   data.clear();
-  expected.min_content_boost = 0.000578369f;
-  expected.offset_sdr = -0.0625f;
-  expected.offset_hdr = -0.0625f;
+  for (int i = 0; i < 3; i++) {
+    expected.min_content_boost[i] = 0.000578369f + i * 0.001f;
+    expected.offset_sdr[i] = -0.0625f + i * 0.001f;
+    expected.offset_hdr[i] = -0.0625f + i * 0.001f;
+  }
   expected.hdr_capacity_max = 1000.0f / 203.0f;
+  expected.use_base_cg = true;
 
   EXPECT_EQ(
       uhdr_gainmap_metadata_frac::gainmapMetadataFloatToFraction(&expected, &metadata).error_code,
@@ -97,13 +106,16 @@ TEST_F(GainMapMetadataTest, encodeMetadataThenDecode) {
                 .error_code,
             UHDR_CODEC_OK);
 
-  EXPECT_FLOAT_EQ(expected.max_content_boost, decodedUHdrMetadata.max_content_boost);
-  EXPECT_FLOAT_EQ(expected.min_content_boost, decodedUHdrMetadata.min_content_boost);
-  EXPECT_FLOAT_EQ(expected.gamma, decodedUHdrMetadata.gamma);
-  EXPECT_FLOAT_EQ(expected.offset_sdr, decodedUHdrMetadata.offset_sdr);
-  EXPECT_FLOAT_EQ(expected.offset_hdr, decodedUHdrMetadata.offset_hdr);
+  for (int i = 0; i < 3; i++) {
+    EXPECT_FLOAT_EQ(expected.max_content_boost[i], decodedUHdrMetadata.max_content_boost[i]);
+    EXPECT_FLOAT_EQ(expected.min_content_boost[i], decodedUHdrMetadata.min_content_boost[i]);
+    EXPECT_FLOAT_EQ(expected.gamma[i], decodedUHdrMetadata.gamma[i]);
+    EXPECT_FLOAT_EQ(expected.offset_sdr[i], decodedUHdrMetadata.offset_sdr[i]);
+    EXPECT_FLOAT_EQ(expected.offset_hdr[i], decodedUHdrMetadata.offset_hdr[i]);
+  }
   EXPECT_FLOAT_EQ(expected.hdr_capacity_min, decodedUHdrMetadata.hdr_capacity_min);
   EXPECT_FLOAT_EQ(expected.hdr_capacity_max, decodedUHdrMetadata.hdr_capacity_max);
+  EXPECT_EQ(expected.use_base_cg, decodedUHdrMetadata.use_base_cg);
 }
 
 }  // namespace ultrahdr
